@@ -7,9 +7,9 @@ Python ``@deprecated`` decorator to deprecate old python classes, functions or m
 
 """
 
-__version__ = "1.2.12"
-__author__ = u"Laurent LAPORTE <tantale.solutions@gmail.com>"
-__date__ = "2020-03-13"
+__version__ = "1.2.15"
+__author__ = u"Laurent LAPORTE <laurent.laporte.pro@gmail.com>"
+__date__ = "2024-11-15"
 __credits__ = "(c) Laurent LAPORTE"
 
 from deprecated.classic import deprecated
